@@ -22,9 +22,9 @@ from .api import (
     analysis_run_list_view,
     analysis_run_detail_view,
     analysis_export_create_view,
-    analysis_send_create_view,
-    analysis_send_detail_view,
-    compute_view
+    analysis_send_list_view,
+    compute_view,
+    oap_get_users
 )
 from .utilities import is_authenticated
 
@@ -92,11 +92,11 @@ class OAPDash(dash.Dash):
         self._add_url("analyses/", analysis_list_view, ['GET', 'POST'])
         self._add_url("analyses/<string:id>/", analysis_detail_view, ['PUT', 'GET', 'DELETE'])
         self._add_url("analysis-runs/", analysis_run_list_view, ['GET'])
-        self._add_url("analysis-runs/<string:id>/", analysis_run_detail_view, ['GET'])
-        self._add_url("analysis-sends/", partial(analysis_send_create_view, self.func_compute), ['POST'])
-        self._add_url("analysis-sends/<string:id>/", analysis_send_detail_view, ['DELETE'])
+        self._add_url("analysis-runs/<string:id>/", analysis_run_detail_view, ['GET', 'DELETE'])
+        self._add_url("analysis-sends/", partial(analysis_send_list_view, self.func_compute), ['POST', 'DELETE'])
         self._add_url("analysis-exports/", analysis_export_create_view, ['POST'])
         self._add_url("compute", partial(compute_view, self.func_compute), ['POST'])
+        self._add_url("oap/users", oap_get_users, ['GET'])
 
     def _index(self, *args, **kwargs):  # pylint: disable=unused-argument
         scripts = self._generate_scripts_html()
