@@ -247,11 +247,11 @@ class ExcelRenderer:
         cell.font = Font(color="00598B")
         cell.fill = PatternFill("solid", fgColor="eeeeee")
 
-        cell = ws['C12']
-        user = self.analysis_run.analysis.app.installed_by
-        cell.value = f'{user.first_name} {user.last_name}'
-        cell.font = Font(color="000000")
-        cell.fill = PatternFill("solid", fgColor="eeeeee")
+        # cell = ws['C12']
+        # user = self.analysis_run.analysis.app.installed_by
+        # cell.value = f'{user.first_name} {user.last_name}'
+        # cell.font = Font(color="000000")
+        # cell.fill = PatternFill("solid", fgColor="eeeeee")
 
         cell = ws['B13']
         cell.value = 'App version'
@@ -305,7 +305,7 @@ class ExcelRenderer:
         :return: Workbook
         """
         self.generate_summary()
-        run_data = self.analysis_run.result['excel-data']
+        run_data = self.analysis_run.get_result().get('excel-data', {})
 
         for sheet in run_data['sheets']:
             ws = self.wb.create_sheet(title=sheet['title'])
